@@ -13,21 +13,6 @@ from napoleontoolbox.signal import signal_utility
 
 import json
 
-
-def reconstitute_signal_perf(data=None, initial_price = 1. , average_execution_cost = 7.5e-4 , transaction_cost = True):
-    data['turn_over'] = abs(data['signal'] - data['signal'].shift(-1).fillna(0.))
-    print('average hourly turn over')
-    print(data['turn_over'].sum() / len(data))
-    data['close_return'] = data['close'].pct_change()
-    data['reconstituted_close'] = metrics.from_ret_to_price(data['close_return'],initial_price=initial_price)
-    data['non_adjusted_perf_return'] = data['close_return'] * data['signal']
-    if transaction_cost :
-        data['perf_return'] = data['non_adjusted_perf_return']- data['turn_over']*average_execution_cost
-    else :
-        data['perf_return'] = data['non_adjusted_perf_return']
-    data['reconstituted_perf'] = metrics.from_ret_to_price(data['perf_return'],initial_price=initial_price)
-    return data
-
 def roll_wrapper(rolled_df, lookback_window, skipping_size, function_to_apply, trigger):
     signal_df = roll(rolled_df, lookback_window).apply(function_to_apply)
     signal_df = signal_df.to_frame()
@@ -70,7 +55,6 @@ class AbstractRunner(ABC):
     def runTrial(self,saver,  seed, trigger, signal_type, idios_string, transaction_costs):
         pass
 
-
 class SimpleSignalRunner(AbstractRunner):
     def runTrial(self, saver, seed, trigger, signal_type, idios_string, transaction_costs):
         idios = json.loads(idios_string)
@@ -105,7 +89,7 @@ class SimpleSignalRunner(AbstractRunner):
             signal_generation_method_to_call = getattr(signal_generator, signal_type)
             hourly_df = roll_wrapper(hourly_df, lookback_window, skipping_size,
                                       lambda x: signal_generation_method_to_call(data=x, **idios), trigger)
-        hourly_df = reconstitute_signal_perf(data = hourly_df, transaction_cost = transaction_costs)
+        hourly_df = signal_utility.reconstitute_signal_perf(data = hourly_df, transaction_cost = transaction_costs)
         sharpe_strat = metrics.sharpe(hourly_df['perf_return'].dropna(), period= 252 * 24, from_ret=True)
         sharpe_under = metrics.sharpe(hourly_df['close_return'].dropna(), period= 252 * 24, from_ret=True)
         print('underlying sharpe')
