@@ -1,5 +1,6 @@
 #!/usr/bin/env python
 # coding: utf-8
+import pandas as pd
 from napoleontoolbox.utility import metrics
 
 def convert_to_sql_column_format(run):
@@ -30,6 +31,18 @@ def recover_to_sql_column_format(run):
     run = run.replace('dodo',':')
     return run
 
+def f_sharpe_signals_mix(data, w):
+    all_signals = [col for col in data.columns if 'signal' in col]
+    N_ = len(all_signals)
+    w = w.reshape([1,N_])
+    temp_df = data[['close', 'signal0']].copy()
+    temp_df = temp_df.rename(columns={"signal0": "signal"}, errors="raise")
+    tt = pd.DataFrame(data[all_signals].values * w, columns=all_signals, index=data.index)
+    temp_df['signal'] = tt.sum(axis=1)
+    hourly_df = reconstitute_signal_perf(data=temp_df, transaction_cost=True, print_turnover=True)
+    sharpe_strat = metrics.sharpe(hourly_df['perf_return'].dropna(), period=252 * 24, from_ret=True)
+    return -sharpe_strat
+
 
 def reconstitute_signal_perf(data=None, initial_price = 1. , average_execution_cost = 7.5e-4 , transaction_cost = True, print_turnover = False):
     data['turn_over'] = abs(data['signal'] - data['signal'].shift(-1).fillna(0.))
